@@ -1,14 +1,8 @@
 nca_output <-
-function (model, plots=FALSE, bottlenecks=FALSE, summaries=TRUE,
+function (model, plots=FALSE, bottlenecks=FALSE, summaries=TRUE, test=FALSE,
           pdf=FALSE, path=NULL) {
   # model needs to be the output of the NCA command
 
-  if (plots) {
-    for(plot in model$plots) {
-      p_display_plot(plot, pdf=pdf, path=path)
-    }
-  }
-
   if (bottlenecks) {
     p_display_bottleneck(model$bottlenecks, pdf=pdf, path=path)
   }
@@ -19,5 +13,21 @@ function (model, plots=FALSE, bottlenecks=FALSE, summaries=TRUE,
     }
   }
 
+  if (plots) {
+    for (plot in model$plots) {
+      p_display_plot(plot, pdf=pdf, path=path)
+    }
+  }
+
+  if (test) {
+    if (length(model$tests) == 0) {
+      message(paste("\nTests are selected in the output,",
+                    "but non were supplied by the analysis!\n"))
+    }
+    for (test in model$tests) {
+      p_display_test(test, pdf=pdf, path=path)
+    }
+  }
+
   cat("")
 }
